/***************************************************************************
 *   Copyright (C) 2005 by Andrew Krause                                   *
 *   Based on gtksourceviewmm by Rob Page                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SOURCEBUFFER_H
#define SOURCEBUFFER_H

#include <glibmm.h>
#include <gdkmm/pixbuf.h>
#include <gtkmm/textbuffer.h>
#include <gtkmm/textview.h>
#include <gtksourceview/gtksourcetagstyle.h>

#include "sourceview/sourcelanguage.h"
#include "sourceview/sourcelanguagesmanager.h"

typedef struct _GtkSourceBuffer GtkSourceBuffer;
typedef struct _GtkSourceBufferClass GtkSourceBufferClass;

namespace Gtk
{ class SourceBuffer_Class; 
}

namespace Gtk
{
  class SourceBuffer : public Gtk::TextBuffer
  {
  public:
    typedef SourceBuffer CppObjectType;
    typedef SourceBuffer_Class CppClassType;
    typedef GtkSourceBuffer BaseObjectType;
    typedef GtkSourceBufferClass BaseClassType;

    SourceBuffer();
    virtual ~SourceBuffer();
  
    static GType get_type()      G_GNUC_CONST;
    static GType get_base_type() G_GNUC_CONST;

    GtkSourceBuffer*       gobj()       { return reinterpret_cast<GtkSourceBuffer*>(gobject_); }
    const GtkSourceBuffer* gobj() const { return reinterpret_cast<GtkSourceBuffer*>(gobject_); }

    Glib::RefPtr <Gtk::SourceLanguagesManager> get_languages_manager();
    bool get_check_brackets ();
    
    void set_check_brackets (bool check=true);
    void set_bracket_match_style(GtkSourceTagStyle*);
    void set_highlight (bool highlight=true);
    void set_max_undo_levels(int max_undo_levels);
    void set_language (Gtk::SourceLanguage*);
    void set_escape_char (gunichar);

    bool get_highlight ();
    int get_max_undo_levels();
    GtkSourceLanguage* get_language();
    gunichar get_escape_char ();
    
    bool can_undo();
    bool can_redo();
    void undo();
    void redo();

    void begin_not_undoable_action();
    void end_not_undoable_action();

  private:
    friend class SourceBuffer_Class;
    static CppClassType sourcebuffer_class_;

    SourceBuffer(const SourceBuffer&);
    SourceBuffer& operator=(const SourceBuffer&);

  protected:
    explicit SourceBuffer(const Glib::ConstructParams& construct_params);
    explicit SourceBuffer(GtkSourceBuffer* castitem);
  };
}


namespace Glib
{ Gtk::SourceBuffer* wrap(GtkSourceBuffer* object, bool take_copy = false);
}

#endif
