/***************************************************************************
 *   Copyright (C) 2005 by Andrew Krause                                   *
 *   Based on work by The gtkmm Development Team                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "sourceview/sourcelanguagesmanager.h"
#include "sourceview/private/sourcelanguagesmanager_p.h"

#include <gtksourceview/gtksourcelanguagesmanager.h>
#include <gtksourceview/gtksourcelanguage.h>


namespace Glib
{
  Glib::RefPtr<Gtk::SourceLanguagesManager> wrap(GtkSourceLanguagesManager* object, bool take_copy)
  { return Glib::RefPtr<Gtk::SourceLanguagesManager>(new Gtk::SourceLanguagesManager(GTK_SOURCE_LANGUAGES_MANAGER ((GObject*)(object))));
  }
}

namespace Gtk
{
  const Glib::Class& SourceLanguagesManager_Class::init()
  {
    if (!gtype_)
    {
      class_init_func_ = &SourceLanguagesManager_Class::class_init_function;
      register_derived_type(gtk_source_languages_manager_get_type());
    }
    return *this;
  }

  void SourceLanguagesManager_Class::class_init_function(void* g_class, void* class_data)
  {
    BaseClassType *const klass = static_cast<BaseClassType*>(g_class);
    CppClassParent::class_init_function(klass, class_data);
  }

  Glib::ObjectBase* SourceLanguagesManager_Class::wrap_new(GObject* o)
  { return new SourceLanguagesManager((GtkSourceLanguagesManager*)(o));
  }

  SourceLanguagesManager::SourceLanguagesManager(const Glib::ConstructParams& construct_params)
                        : Glib::Object(construct_params)
  {
  }

  SourceLanguagesManager::SourceLanguagesManager(GtkSourceLanguagesManager* castitem)
  : Glib::Object((GObject*)(castitem))
  {
  }

  SourceLanguagesManager::~SourceLanguagesManager()
  {
  }

  SourceLanguagesManager::CppClassType SourceLanguagesManager::sourcelanguagesmanager_class_; // initialize static member

  GType SourceLanguagesManager::get_type()
  { return sourcelanguagesmanager_class_.init().get_type();
  }

  GType SourceLanguagesManager::get_base_type()
  { return gtk_source_languages_manager_get_type();
  }


  SourceLanguagesManager::SourceLanguagesManager()
                        : Glib::ObjectBase(0),
                          Glib::Object(Glib::ConstructParams(sourcelanguagesmanager_class_.init()))
  {
  }

  const GSList* SourceLanguagesManager::get_available_languages()
  { return gtk_source_languages_manager_get_available_languages(gobj());
  }

  Gtk::SourceLanguage* SourceLanguagesManager::get_language_from_mime_type (const Glib::ustring mime_type)
  { return (new Gtk::SourceLanguage (GTK_SOURCE_LANGUAGE(gtk_source_languages_manager_get_language_from_mime_type(gobj(), mime_type.c_str()))));
  }

  const GSList* SourceLanguagesManager::get_lang_files_dirs()
  { return gtk_source_languages_manager_get_lang_files_dirs(gobj());
  }
}
